@@ -9,6 +9,7 @@ from filetype import guess_extension
 
 from .database import Connection
 from .database import delete
+from .database import get_entry
 from .database import insert
 from .database import select
 from .database import tiered_path
@@ -69,11 +70,6 @@ def exist_submission(db: Connection, submission_id: int) -> bool:
     return bool(select(db, submissions_table, ["ID"], ["ID"], [submission_id]).fetchone())
 
 
-def remove_submission(db: Connection, submission_id: int):
-    delete(db, submissions_table, "ID", submission_id)
-    db.commit()
-
-
 def save_submission(db: Connection, submission: Dict[str, Union[str, int]], file: Optional[bytes]):
     file_ext: str = ""
     file_url_name: str = submission["file_url"].split("/")[-1]
@@ -105,6 +101,15 @@ def save_submission(db: Connection, submission: Dict[str, Union[str, int]], file
     db.commit()
 
 
+def remove_submission(db: Connection, submission_id: int):
+    delete(db, submissions_table, "ID", submission_id)
+    db.commit()
+
+
+def get_submission(db: Connection, submission_id: int) -> Optional[Dict[str, Union[str, int]]]:
+    return get_entry(db, submissions_table, submissions_fields, "ID", submission_id)
+
+
 def search_submissions(db: Connection,
                        author: List[str] = None, title: List[str] = None,
                        date: List[str] = None, description: List[str] = None, tags: List[str] = None,
