@@ -7,6 +7,7 @@ from typing import Union
 from .database import Connection
 from .database import Cursor
 from .database import delete
+from .database import get_entry
 from .database import insert
 from .database import select
 from .database import update
@@ -71,6 +72,33 @@ def remove_user(db: Connection, user: str):
     db.commit()
 
 
+def get_user(db: Connection, username: str) -> Optional[Dict[str, Union[str, int]]]:
+    return get_entry(db, users_table, users_fields, "ID", username)
+
+
+def enable_user(db: Connection, user: str):
+    folders_result: Optional[Tuple[str, ...]] = select(db, users_table, ["FOLDERS"], ["USERNAME"], [user]).fetchone()
+
+    if folders_result is None:
+        return
+
+    edit_user_field_replace(db, user, ["FOLDERS"], [folders_result[0].replace("!", "")])
+
+
+def disable_user(db: Connection, user: str):
+    folders_result: Optional[Tuple[str, ...]] = select(db, users_table, ["FOLDERS"], ["USERNAME"], [user]).fetchone()
+
+    if folders_result is None:
+        return
+
+    folders: List[str] = [
+        f"!{f}" if f.lower() in ("gallery", "scraps", "favorites") else f
+        for f in filter(bool, folders_result[0].split(","))
+    ]
+
+    edit_user_field_replace(db, user, ["FOLDERS"], [",".join(folders)])
+
+
 def edit_user_field_replace(db: Connection, user: str, fields: List[str], new_values: List[str]):
     update(db, users_table, fields, new_values, "USERNAME", user)
     db.commit()
